==> metavoidapi-1.0.0.tar.gz: metavoidapi-1.0.0/README.md <==
# **METAVOID WRAPPER**


_This is a an official Wrapper for matavoid Api. To let users to use api with ease._


## Examples:

To get language translation 

```
from meta_api import META
x = META()
print(x.translate("hello", "hi"))
```

To get wallpaper images

```
from meta_api import META
x = META()
print(x.wallpaper("Pokemon", "1"))
```

To get anime images

```
from meta_api import META
x = META()
print(x.animeimage("sfw", "slap"))
```

To get youtube dl

```
from meta_api import META
x = META()
print(x.yt_dl("https://youtu.be/jzD_yyEcp0M"))
```

To get facebook dl

```
from meta_api import META
x = META()
print(x.fb_dl("https://www.facebook.com/watch/1424858414264105/&ved=2ahUKEwjQ1b6Vt9D3AhXLSWwGHd2rDxEQo7QBegQIAxAB&usg=AOvVaw0Cw1hhGO9eVB5PUERZGeY6"))
```

To get instagram dl

```
from meta_api import META
x = META()
print(x.insta_dl("https://www.instagram.com/reel/Cc3MP9YBmNX/?igshid=YmMyMTA2M2Y="))
```

To get twiter dl

```
from meta_api import META
x = META()
print(x.twitter_dl("https://twitter.com/2020Fights/status/1521209796782919680?s=20&t=b8YyzXIkHfrbEwMfcZZI7A"))
```

To get  Wikipedia 


```
from meta_api import META
x = META()
print(x.wiki("pokemon", "en"))
```

To get urban 


```
from meta_api import META
x = META()
print(x.urban("pokemon", "1"))
```

To get urban random


```
from meta_api import META
x = META()
print(x.urban_random())
```

To get manga search


```
from meta_api import META
x = META()
print(x.manga_search("pokemon", "1"))
```

To get manga detail


```
from meta_api import META
x = META()
print(x.manga_detail("manga-sb969684"))
```

To get manga dl


```
from meta_api import META
x = META()
print(x.mangadl("manga-sb969684", "2"))
```

To get gogoanime dl


```
from meta_api import META
x = META()
print(x.gogoanimedl("pokemon-xy-episode-2"))
```

To get torrent nyaa


```
from meta_api import META
x = META()
print(x.torrent_nyaa("pokemon", "1"))
```

To get torrent 1337x


```
from meta_api import META
x = META()
print(x.torrent_nyaa("pokemon", "1"))
```

<i>Checkout code at <a href="github.com/tamilvip007/meta_api/blob/master/main.py">main.py</a></i>

==> metavoidapi-1.0.2.tar.gz: metavoidapi-1.0.2/README.md <==
# **METAVOID WRAPPER**


_This is a an official Wrapper for matavoid Api. To let users to use api with ease._


## Examples:

To get language translation 

```
from metaapi import META
x = META()
print(x.translate("hello", "hi"))
```

To get wallpaper images

```
from metaapi import META
x = META()
print(x.wallpaper("Pokemon", "1"))
```

To get anime images

```
from metaapi import META
x = META()
print(x.animeimage("sfw", "slap"))
```

To get youtube dl

```
from metaapi import META
x = META()
print(x.yt_dl("https://youtu.be/jzD_yyEcp0M"))
```

To get facebook dl

```
from metaapi import META
x = META()
print(x.fb_dl("https://www.facebook.com/watch/1424858414264105/&ved=2ahUKEwjQ1b6Vt9D3AhXLSWwGHd2rDxEQo7QBegQIAxAB&usg=AOvVaw0Cw1hhGO9eVB5PUERZGeY6"))
```

To get instagram dl

```
from metaapi import META
x = META()
print(x.insta_dl("https://www.instagram.com/reel/Cc3MP9YBmNX/?igshid=YmMyMTA2M2Y="))
```

To get twiter dl

```
from metaapi import META
x = META()
print(x.twitter_dl("https://twitter.com/2020Fights/status/1521209796782919680?s=20&t=b8YyzXIkHfrbEwMfcZZI7A"))
```

To get  Wikipedia 


```
from metaapi import META
x = META()
print(x.wiki("pokemon", "en"))
```

To get urban 


```
from metaapi import META
x = META()
print(x.urban("pokemon", "1"))
```

To get urban random


```
from metaapi import META
x = META()
print(x.urban_random())
```

To get manga search


```
from metaapi import META
x = META()
print(x.manga_search("pokemon", "1"))
```

To get manga detail


```
from metaapi import META
x = META()
print(x.manga_detail("manga-sb969684"))
```

To get manga dl


```
from metaapi import META
x = META()
print(x.mangadl("manga-sb969684", "2"))
```

To get gogoanime dl


```
from metaapi import META
x = META()
print(x.gogoanimedl("pokemon-xy-episode-2"))
```

To get torrent nyaa


```
from metaapi import META
x = META()
print(x.torrent_nyaa("pokemon", "1"))
```

To get torrent 1337x


```
from metaapi import META
x = META()
print(x.torrent_nyaa("pokemon", "1"))
```

<i>Checkout code at <a href="github.com/metavoidteam/MetaApi-Py/blob/master/main.py">main.py</a></i>
